interface MCHelperOptions {
    /**
     * The URL of the signaling server.
     * @example "wss://example.com:8080"
     */
    signalingServerUrl: string;
    /**
     * The ID of the peer.
     * If not set, will be generated using `nanoid(6)`.
     * @default nanoid(6)
     */
    id?: string;
    /**
     * Whether to print debug information.
     * @default false
     */
    debug?: boolean;
    /**
     * ICE servers.
     * @default
     * [
     *  { urls: 'stun:stun.l.google.com:19302', }
     * ]
     */
    iceServers?: RTCIceServer[];
    /**
     * Room id.
     *
     * Same room id will be able to communicate with each other.
     */
    roomId: string;
}
declare class MCHelper {
    #private;
    constructor(options: MCHelperOptions);
    get id(): string;
    broadcast<T>(message: T): void;
    /**
     * @returns cleanup fn
     */
    onBroadcast<T>(callback: (message: MessageEvent<T>) => void): () => void;
    close(): void;
}

export { MCHelper, type MCHelperOptions };
